@@ -104,9 +104,10 @@ class ContextProvider(ABC):
         return NotImplemented
 
 class Texts(ContextProvider):
-    def __init__(self, text: Optional[Union[str, Callable[[], str]]] = None, name: Optional[str] = None, visible: bool = True):
+    def __init__(self, text: Optional[Union[str, Callable[[], str]]] = None, name: Optional[str] = None, visible: bool = True, newline: bool = False):
         if text is None and name is None:
             raise ValueError("Either 'text' or 'name' must be provided.")
+        self.newline = newline
 
         # Ensure that non-callable inputs are treated as strings
         if not callable(text):
@@ -127,6 +128,11 @@ class Texts(ContextProvider):
         else:
             _name = name
         super().__init__(_name, visible=visible)
+        if not self._is_dynamic:
+            self._cached_content = self.content
+            # The content is cached, but it's still "stale" from the perspective
+            # of the async refresh cycle. Let the first refresh formalize it.
+            self._is_stale = True
 
     async def refresh(self):
         if self._is_dynamic:
@@ -190,6 +196,10 @@ class Tools(ContextProvider):
     def __init__(self, tools_json: Optional[List[Dict]] = None, name: str = "tools", visible: bool = True):
         super().__init__(name, visible=visible)
         self._tools_json = tools_json or []
+        # Pre-render and cache the content, but leave it stale for the first refresh
+        if self._tools_json:
+            self._cached_content = f"<tools>{str(self._tools_json)}</tools>"
+        self._is_stale = True
     def update(self, tools_json: List[Dict]):
         self._tools_json = tools_json
         self.mark_stale()
@@ -288,6 +298,9 @@ class Images(ContextProvider):
     def __init__(self, url: str, name: Optional[str] = None, visible: bool = True):
         super().__init__(name or url, visible=visible)
         self.url = url
+        if self.url.startswith("data:"):
+            self._cached_content = self.url
+        self._is_stale = True
     def update(self, url: str):
         self.url = url
         self.mark_stale()
@@ -311,19 +324,21 @@ class Images(ContextProvider):
 
 # 3. 消息类 (已合并 MessageContent)
 class Message(ABC):
-    def __init__(self, role: str, *initial_items: Union[ContextProvider, str, list]):
+    def __init__(self, role: str, *initial_items: Union[ContextProvider, str, list, 'Message']):
         self.role = role
         processed_items = []
         for item in initial_items:
             if item is None:
                 continue
-            if isinstance(item, str):
-                # Check if the string contains placeholders from f-string rendering
+
+            # This is the new recursive flattening logic
+            if isinstance(item, Message):
+                processed_items.extend(item.provider())
+            elif isinstance(item, str):
                 import re
                 placeholder_pattern = re.compile(r'(__provider_placeholder_[a-f0-9]{32}__)')
                 parts = placeholder_pattern.split(item)
-
-                if len(parts) > 1: # Placeholders were found
+                if len(parts) > 1:
                     for part in parts:
                         if not part: continue
                         if placeholder_pattern.match(part):
@@ -332,18 +347,14 @@ class Message(ABC):
                                 processed_items.append(provider)
                         else:
                             processed_items.append(Texts(text=part))
-                else: # No placeholders, just a regular string
+                else:
                     processed_items.append(Texts(text=item))
-
-            elif isinstance(item, Message):
-                processed_items.extend(item.provider())
             elif isinstance(item, ContextProvider):
                 processed_items.append(item)
             elif isinstance(item, list):
                 for sub_item in item:
                     if not isinstance(sub_item, dict) or 'type' not in sub_item:
                         raise ValueError("List items must be dicts with a 'type' key.")
-
                     item_type = sub_item['type']
                     if item_type == 'text':
                         processed_items.append(Texts(text=sub_item.get('text', '')))
@@ -373,8 +384,11 @@ class Message(ABC):
         for item in self._items:
             block = item.get_content_block()
             if block and block.content is not None:
+                # Check if it's a Texts provider with newline=True
+                # and it's not the very first item with content.
+                if isinstance(item, Texts) and hasattr(item, 'newline') and item.newline and final_parts:
+                    final_parts.append("\n\n")
                 final_parts.append(block.content)
-
         return "".join(final_parts)
 
     def pop(self, name: str) -> Optional[ContextProvider]:
@@ -468,16 +482,62 @@ class Message(ABC):
         # and our custom __eq__ on ContextProvider handles the comparison logic.
         return item in self._items
 
+    def has(self, provider_type: type) -> bool:
+        """Checks if the message contains a provider of a specific type."""
+        if not isinstance(provider_type, type) or not issubclass(provider_type, ContextProvider):
+            raise TypeError("provider_type must be a subclass of ContextProvider")
+        return any(isinstance(p, provider_type) for p in self._items)
+
+    def lstrip(self, provider_type: type):
+        """
+        从消息的左侧（开头）移除所有指定类型的 provider。
+        移除操作会一直持续，直到遇到一个不同类型的 provider 为止。
+        """
+        while self._items and type(self._items[0]) is provider_type:
+            self.pop(self._items[0].name)
+
+    def rstrip(self, provider_type: type):
+        """
+        从消息的右侧（末尾）移除所有指定类型的 provider。
+        移除操作会一直持续，直到遇到一个不同类型的 provider 为止。
+        """
+        while self._items and type(self._items[-1]) is provider_type:
+            self.pop(self._items[-1].name)
+
+    def strip(self, provider_type: type):
+        """
+        从消息的两侧移除所有指定类型的 provider。
+        """
+        self.lstrip(provider_type)
+        self.rstrip(provider_type)
+
     def __bool__(self) -> bool:
         return bool(self._items)
     def get(self, key: str, default: Any = None) -> Any:
         """提供类似字典的 .get() 方法来访问属性。"""
         return getattr(self, key, default)
 
-    async def render_latest(self) -> Optional[Dict[str, Any]]:
-        """Refreshes all providers in the message and returns the rendered dictionary."""
+    async def refresh(self):
+        """刷新此消息中的所有 provider。"""
         tasks = [provider.refresh() for provider in self._items]
         await asyncio.gather(*tasks)
+
+    async def render(self) -> Optional[Dict[str, Any]]:
+        """
+        渲染消息为字典。首次调用时会隐式刷新以确保动态内容被加载。
+        后续调用将返回缓存版本，除非手动调用了 refresh()。
+        """
+        # 检查是否是首次渲染
+        is_first_render = not all(hasattr(p, '_cached_content') and p._cached_content is not None for p in self._items if p._is_stale)
+
+        if is_first_render:
+            await self.refresh()
+
+        return self.to_dict()
+
+    async def render_latest(self) -> Optional[Dict[str, Any]]:
+        """始终刷新并返回最新的渲染结果。"""
+        await self.refresh()
         return self.to_dict()
 
     def to_dict(self) -> Optional[Dict[str, Any]]:
@@ -550,12 +610,20 @@ class ToolCalls(Message):
 
 class ToolResults(Message):
     """Represents a tool message with the result of a single tool call."""
-    def __init__(self, tool_call_id: str, content: str):
-        # We pass a Texts provider to the parent so it can be rendered,
-        # but the primary way to access content for ToolResults is via its dict representation.
-        super().__init__("tool", Texts(text=content))
+    def __init__(self, tool_call_id: str, content: Union[str, Message]):
+        # The base Message class now handles the absorption of a Message object.
+        # We just need to pass the content to the parent __init__.
+        # For ToolResults, we primarily care about the textual content.
+        if isinstance(content, Message):
+             # Extract only text-like providers to pass to the parent
+            text_providers = [p for p in content.provider() if not isinstance(p, Images)]
+            super().__init__("tool", *text_providers)
+        else:
+            super().__init__("tool", content)
+
         self.tool_call_id = tool_call_id
-        self._content = content
+        # After initialization, render the content to a simple string for _content.
+        self._content = self._render_content()
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -735,7 +803,8 @@ class Messages:
 
     def __len__(self) -> int: return len(self._messages)
     def __iter__(self): return iter(self._messages)
-
+    def __repr__(self):
+        return f"Messages({repr(self._messages)})"
     def __contains__(self, item: Any) -> bool:
         """Checks if a Message or ContextProvider is in the collection."""
         if isinstance(item, Message):
