@@ -8,7 +8,7 @@ from datetime import datetime
 
 from .log_config import logger
 
-from .utils import safe_get, generate_sse_response, generate_no_stream_response, end_of_line, parse_json_safely
+from .utils import safe_get, generate_sse_response, generate_no_stream_response, end_of_line, parse_json_safely, upload_image_to_0x0st
 
 async def check_response(response, error_log):
     if response and not (200 <= response.status_code < 300):
@@ -45,8 +45,8 @@ async def gemini_json_poccess(response_json):
     if is_thinking:
         content = safe_get(json_data, "parts", 1, "text", default="")
 
-    function_call_name = safe_get(json_data, "functionCall", "name", default=None)
-    function_full_response = safe_get(json_data, "functionCall", "args", default="")
+    function_call_name = safe_get(json_data, "parts", 0, "functionCall", "name", default=None)
+    function_full_response = safe_get(json_data, "parts", 0, "functionCall", "args", default="")
     function_full_response = await asyncio.to_thread(json.dumps, function_full_response) if function_full_response else None
 
     blockReason = safe_get(json_data, 0, "promptFeedback", "blockReason", default=None)
@@ -78,7 +78,7 @@ async def fetch_gemini_response_stream(client, url, headers, payload, model, tim
                     try:
                         response_json = await asyncio.to_thread(json.loads, parts_json)
                     except json.JSONDecodeError:
-                        logger.error(f"JSON decode error: {parts_json}")
+                        # logger.error(f"JSON decode error: {parts_json}")
                         continue
                 else:
                     parts_json += line
@@ -99,7 +99,12 @@ async def fetch_gemini_response_stream(client, url, headers, payload, model, tim
                     yield sse_string
 
                 if image_base64:
-                    yield await generate_no_stream_response(timestamp, model, content=content, tools_id=None, function_call_name=None, function_call_content=None, role=None, total_tokens=totalTokenCount, prompt_tokens=promptTokenCount, completion_tokens=candidatesTokenCount, image_base64=image_base64)
+                    if "gemini-2.5-flash-image" not in model:
+                        yield await generate_no_stream_response(timestamp, model, content=content, tools_id=None, function_call_name=None, function_call_content=None, role=None, total_tokens=totalTokenCount, prompt_tokens=promptTokenCount, completion_tokens=candidatesTokenCount, image_base64=image_base64)
+                    else:
+                        image_url = await upload_image_to_0x0st("data:image/png;base64," + image_base64)
+                        sse_string = await generate_sse_response(timestamp, model, content=f"\n\n![image]({image_url})")
+                        yield sse_string
 
                 if function_call_name:
                     sse_string = await generate_sse_response(timestamp, model, content=None, tools_id="chatcmpl-9inWv0yEtgn873CxMBzHeCeiHctTV", function_call_name=function_call_name)
@@ -277,7 +282,8 @@ async def fetch_gpt_response_stream(client, url, headers, payload, timeout):
                     openrouter_reasoning = safe_get(line, "choices", 0, "delta", "reasoning", default="")
                     openrouter_base64_image = safe_get(line, "choices", 0, "delta", "images", 0, "image_url", "url", default="")
                     if openrouter_base64_image:
-                        sse_string = await generate_sse_response(timestamp, payload["model"], content=f"\n\n![image]({openrouter_base64_image})")
+                        image_url = await upload_image_to_0x0st(openrouter_base64_image)
+                        sse_string = await generate_sse_response(timestamp, payload["model"], content=f"\n\n![image]({image_url})")
                         yield sse_string
                         continue
                     azure_databricks_claude_summary_content = safe_get(line, "choices", 0, "delta", "content", 0, "summary", 0, "text", default="")
